package org.rcisoft.bus.wmsgoodsstock.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.bus.wmsgoods.entity.WmsGoods;
import org.rcisoft.bus.wmsgoodsstock.dto.WmsGoodsStockPageResultsDto;
import org.rcisoft.bus.wmsgoodsstock.entity.WmsGoodsStock;
import org.rcisoft.bus.wmsgoodsstock.service.WmsGoodsStockService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
* Created by cy on 2024年5月29日 下午1:21:49.
*/
@RestController
@RequestMapping("/wmsgoodsstock")
public class WmsGoodsStockController extends CyPaginationController<WmsGoodsStockPageResultsDto> {


    @Autowired
    private WmsGoodsStockService wmsGoodsStockServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:add')")
    @CyOpeLogAnno(title = "system-库存管理表管理-新增库存管理表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加库存管理表", notes="添加库存管理表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid WmsGoodsStock wmsGoodsStock, BindingResult bindingResult) {
        CyPersistModel data = wmsGoodsStockServiceImpl.persist(wmsGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsStock);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:delete')")
    @CyOpeLogAnno(title = "system-库存管理表管理-删除库存管理表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除库存管理表", notes="逻辑删除库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,WmsGoodsStock wmsGoodsStock) {
        wmsGoodsStock.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsStockServiceImpl.removeLogical(wmsGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:delete')")
    @CyOpeLogAnno(title = "system-库存管理表管理-删除库存管理表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除库存管理表", notes="删除库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,WmsGoodsStock wmsGoodsStock) {
        wmsGoodsStock.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsStockServiceImpl.remove(wmsGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:update')")
    @CyOpeLogAnno(title = "system-库存管理表管理-修改库存管理表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改库存管理表", notes="修改库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid WmsGoodsStock wmsGoodsStock, BindingResult bindingResult) {
        wmsGoodsStock.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsStockServiceImpl.merge(wmsGoodsStock);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsStock);
    }
    @CyOpeLogAnno(title = "system-库存管理表管理-修改库存管理表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改库存管理表", notes="修改库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateCounts/{businessId:\\w+}")
    public CyResult updateCounts(@PathVariable int businessId, @Valid WmsGoodsStock wmsGoodsStock, BindingResult bindingResult) {
        wmsGoodsStock.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsStockServiceImpl.updateCounts(wmsGoodsStock);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                wmsGoodsStock);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:query')")
    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一库存管理表", notes="查询单一库存管理表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsStockServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:list')")
    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询库存管理表集合", notes="查询库存管理表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(WmsGoodsStock wmsGoodsStock) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            wmsGoodsStockServiceImpl.findAll(wmsGoodsStock));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsStock:list')")
    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询库存管理表集合", notes="分页查询库存管理表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(WmsGoodsStockPageResultsDto wmsGoodsStock) {
        wmsGoodsStockServiceImpl.findAllByPagination(getPaginationUtility(), wmsGoodsStock);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-库存管理表管理-查询库存管理表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出库存管理表信息", notes = "导出库存管理表信息")
    @GetMapping(value = "/export")
    public void outWmsGoodsStock(HttpServletResponse response,WmsGoodsStock wmsGoodsStock,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="库存管理表信息.xls";break;
            case "1": excelName="库存管理表信息.xlsx";break;
            case "2": excelName="库存管理表信息.csv";break;
        }
        List<WmsGoodsStock> wmsGoodsStockList = wmsGoodsStockServiceImpl.export(wmsGoodsStock);
        CyEpExcelUtil.exportExcel(wmsGoodsStockList, "库存管理表信息", "库存管理表信息", WmsGoodsStock.class, excelName, response);
    }


    @CyOpeLogAnno(title = "system-商品信息表管理-查询商品", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询商品", notes="查询商品")
    @GetMapping(value = "/detailByCode")
    public CyResult detailByCode(WmsGoods wmsGoods) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                wmsGoodsStockServiceImpl.queryWmsGoodsStock(wmsGoods));
    }
}
